==> Guppi-0.35.2.tar.gz: Guppi-0.35.2/src/libguppiuseful/guppi-useful.h <==
/* $Id: guppi-useful.h,v 1.19 2000/11/11 17:41:51 trow Exp $ */

/*
 * guppi-useful.h
 *
 * Copyright (C) 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org>
 * and Havoc Pennington <hp@pobox.com>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef _INC_GUPPI_USEFUL_H
#define _INC_GUPPI_USEFUL_H

#include <guppi-convenient.h>
#include <guppi-debug.h>
#include <guppi-dialogs.h>
#include <guppi-defaults.h>
#include <guppi-enums.h>
#include <guppi-exit.h>
#include <guppi-file.h>
#include <guppi-guile.h>
#include <guppi-metrics.h>
#include <guppi-paths.h>
#include <guppi-plug-in-spec.h>
#include <guppi-plug-in.h>
#include <guppi-progress.h>
#include <guppi-rgb.h>
#include <guppi-scripting.h>
#include <guppi-splash.h>
#include <guppi-stream.h>
#include <guppi-stream-preview.h>
#include <guppi-string.h>
#include <guppi-timer.h>
#include <guppi-version.h>

#include <guppi-defs.h>

BEGIN_GUPPI_DECLS

void guppi_useful_init (void);
void guppi_useful_init_without_guile (void);

END_GUPPI_DECLS

#endif /* _INC_GUPPI_USEFUL_H */

/* $Id: guppi-useful.h,v 1.19 2000/11/11 17:41:51 trow Exp $ */

==> Guppi-0.40.0-pre1.tar.gz: Guppi-0.35.666/src/libguppiuseful/guppi-useful.h <==
/* $Id: guppi-useful.h,v 1.21 2001/09/08 05:50:00 trow Exp $ */

/*
 * guppi-useful.h
 *
 * Copyright (C) 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org>
 * and Havoc Pennington <hp@pobox.com>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef _INC_GUPPI_USEFUL_H
#define _INC_GUPPI_USEFUL_H

#include <guppi-convenient.h>
#include <guppi-debug.h>
#include <guppi-dialogs.h>
#include <guppi-defaults.h>
#include <guppi-enums.h>
#include <guppi-exit.h>
#include <guppi-file.h>
#include <guppi-guile.h>
#include <guppi-matrix.h>
#include <guppi-metrics.h>
#include <guppi-paths.h>
#include <guppi-plug-in-spec.h>
#include <guppi-plug-in.h>
#include <guppi-progress.h>
#include <guppi-rgb.h>
#include <guppi-scripting.h>
#include <guppi-stream.h>
#include <guppi-stream-preview.h>
#include <guppi-string.h>
#include <guppi-timer.h>
#include <guppi-version.h>

#include <guppi-defs.h>

BEGIN_GUPPI_DECLS

void guppi_useful_init (void);
void guppi_useful_init_without_guile (void);

END_GUPPI_DECLS

#endif /* _INC_GUPPI_USEFUL_H */

/* $Id: guppi-useful.h,v 1.21 2001/09/08 05:50:00 trow Exp $ */
